#!/bin/bash

# Skip premature MN GEO FLOAT IP setup, if we are in the process of initialization:
# - check for running UHAM to detect GEO system initialization state!
if [ ! -f /var/run/uham.pid ]
then
	exit 0
fi

# set/unset tracking geo-float IP if it is configured in clish 
# $1 = start|stop
function setTrackingFloatIP
{
	TRACKFLOAT=$(/sbin/cfg-getparams.sh mmGeoMnTrackingFloatIpAddr)
	[ "$TRACKFLOAT" = "" ] && return 0 # not configured
	#get interface name 
	if [ "$(/sbin/cfg-getparams.sh mmMnChassisType)" == "OPENSTACK" ]; then 
		#MN_INTF_NAME=$(/sbin/eth_from_ip.py $TRACKFLOAT)
		MN_IP=$(/sbin/cfg-getparams.sh localMnIpAddress | cut -d '/' -f1)
		MN_INTF_NAME=$(/sbin/eth_from_ip.py $MN_IP)
		if [ "$MN_INTF_NAME" = "" ]; then 
			echo "${0} ${@}: error get interface name for $MN_IP ip!" | /usr/bin/logger -p user.alert --
			return 1
		fi
	else 
		MN_INTF_NAME=bond0
		MN_VLAN=$(/sbin/cfg-getparams.sh mmMnVlan)
		[ "$MN_VLAN" != "" ] && MN_INTF_NAME=$MN_INTF_NAME.$MN_VLAN
	fi
	#set/unset tracking float ip
	/etc/ha.d/resource.d/IPaddr2 $TRACKFLOAT/32/$MN_INTF_NAME $1
	if [ $? -ne 0 ]; then 
		echo "${0} ${@}: error setting tracking float ip ($TRACKFLOAT/32/$MN_INTF_NAME $1)!" | /usr/bin/logger -p user.alert --
	fi
}

# Run only when called with "start" or "stop" first parameter.
if [ "x${1}" == "xstart" ] || [ "x${1}" == "xstop" ]
then
	GEO_REDUNDANCY_TYPE=$(/sbin/cfg-getparams.sh mmGeoRedundancyType)
	ec=$?
	if [ $ec -ne 0 ]
	then
		echo "${0} ${@}: ERROR getting redundancy type!"
		exit $ec
	fi
	# Run only within a GEO configuration.
	if [ "x${GEO_REDUNDANCY_TYPE}" == "xredundant" ]
	then
		# Run if requested by GHAM or if this is the current BUSY location
		# (i.e. when requested by HB to speed up IP setup on HSB switchover).
		if [ "x${2}" == "xgham" ] || [ -f /var/lib/misc/wasBusy ]
		then
			GEO_MN_FLOAT_IP=$(/sbin/cfg-getparams.sh mmGeoMnFloatIpAddr)
			ec=$?
			if [ "x${GEO_MN_FLOAT_IP}" == "x" ]
			then
				# Not to be treated as error:
				#echo "${0} ${@}: MN GEO-FLOAT IP not configured - working without it!"
				setTrackingFloatIP $1
				exit 0
			fi
			if [ $ec -ne 0 ]
			then
				echo "${0} ${@}: ERROR getting MN GEO-FLOAT IP!"
				setTrackingFloatIP $1
				exit $ec
			fi

			chassis=$(/sbin/cfg-getparams.sh mmMnChassisType)
			if [ "$chassis" == "OPENSTACK" ]
			then
				# check L2/L3 geo type, if L3 use local mgmt IP addr, because voip float net is not same as mgmt net
				geoType=$(/sbin/cfg-getparams.sh mmGeoL2L3Type)
				if [ "${geoType}" == "L3" ]
				then
					mgmtLocalIP=$(/sbin/cfg-getparams.sh localMnIpAddress | cut -d '/' -f1)

					# get interface name based on mgmt IP address
                                	mgmt_intf=`/sbin/eth_from_ip.py ${mgmtLocalIP}`
				else	
					# get interface name based on mgmt IP address
					mgmt_intf=`/sbin/eth_from_ip.py ${GEO_MN_FLOAT_IP}`
				fi
			else
				mgmtVlan=$(/sbin/cfg-getparams.sh mmMnVlan)
				if [ "$mgmtVlan" == "" ]
				then
					mgmt_intf="bond0"
				else
					mgmt_intf="bond0.$mgmtVlan"
				fi
			fi

			if [ "x$mgmt_intf" == "x" ]
			then
				echo "${0} ${@}: ERROR setting MN GEO-FLOAT IP - empty mgmt interface!"
				#still try to set tracking ip
				setTrackingFloatIP $1 
				exit 1
			fi

			/etc/ha.d/resource.d/IPaddr2 ${GEO_MN_FLOAT_IP}/32/${mgmt_intf} $1
			ec=$?
			setTrackingFloatIP $1 $mgmt_intf
			if [ $ec -ne 0 ]
			then
				echo "${0} ${@}: ERROR setting MN GEO-FLOAT IP!"
				exit $ec
			fi
		fi
	fi
fi

exit 0
